@@ -74,7 +74,6 @@ mod tests {
         legacy_version_file = true
         legacy_version_file_disable_tools = []
         libgit2 = true
-        node_compile = false
         not_found_auto_install = true
         paranoid = false
         pipx_uvx = false
@@ -89,6 +88,8 @@ mod tests {
         vfox = false
         yes = true
 
+        [node]
+
         [ruby]
         default_packages_file = "~/.default-gems"
         ruby_build_repo = "https://github.com/rbenv/ruby-build.git"
