@@ -75,7 +75,11 @@ impl Config {
             .chain(DEFAULT_CONFIG_FILENAMES.iter())
             .cloned()
             .collect_vec();
-        let config_paths = load_config_paths(&config_filenames);
+        let config_paths = load_config_paths(&config_filenames)
+            .into_iter()
+            .unique_by(|p| p.canonicalize().unwrap_or_else(|_| p.clone()))
+            .collect_vec();
+        trace!("load: config_paths: {:?}", config_paths);
         let config_files = load_all_config_files(&config_paths, &legacy_files)?;
 
         let config = Self {
@@ -128,7 +132,10 @@ impl Config {
         })
     }
     pub fn env_results(&self) -> eyre::Result<&EnvResults> {
-        self.env.get_or_try_init(|| self.load_env())
+        trace!("env_results: start");
+        let res = self.env.get_or_try_init(|| self.load_env());
+        trace!("env_results: {:#?}", &res);
+        res
     }
     pub fn path_dirs(&self) -> eyre::Result<&Vec<PathBuf>> {
         Ok(&self.env_results()?.env_paths)
@@ -238,14 +245,8 @@ impl Config {
             .collect())
     }
 
-    fn load_tasks_in_dir(&self, dir: &Path) -> Result<Vec<Task>> {
-        let configs = self.configs_at_root(dir);
-        let config_tasks = configs
-            .par_iter()
-            .flat_map(|cf| cf.tasks())
-            .cloned()
-            .collect::<Vec<_>>();
-        let includes = configs
+    pub fn task_includes_for_dir(&self, dir: &Path) -> Vec<PathBuf> {
+        self.configs_at_root(dir)
             .iter()
             .find_map(|cf| cf.task_config().includes.clone())
             .unwrap_or_else(default_task_includes)
@@ -255,7 +256,17 @@ impl Config {
             .collect::<Vec<_>>()
             .into_iter()
             .unique()
+            .collect::<Vec<_>>()
+    }
+
+    pub fn load_tasks_in_dir(&self, dir: &Path) -> Result<Vec<Task>> {
+        let configs = self.configs_at_root(dir);
+        let config_tasks = configs
+            .par_iter()
+            .flat_map(|cf| cf.tasks())
+            .cloned()
             .collect::<Vec<_>>();
+        let includes = self.task_includes_for_dir(dir);
         let extra_tasks = includes
             .par_iter()
             .filter(|p| {
@@ -282,13 +293,14 @@ impl Config {
             .into_iter()
             .chain(config_tasks)
             .chain(extra_tasks)
+            .sorted_by_cached_key(|t| t.name.clone())
             .collect())
     }
 
     fn load_task_file(&self, path: &Path) -> Result<Vec<Task>> {
         let raw = file::read_to_string(path)?;
         let mut tasks = toml::from_str::<HashMap<String, Task>>(&raw)
-            .map_err(|e| eyre!("Error parsing task file: {} {e}", display_path(path)))?;
+            .wrap_err_with(|| format!("Error parsing task file: {}", display_path(path)))?;
         for (name, task) in &mut tasks {
             task.name = name.clone();
             task.config_source = path.to_path_buf();
@@ -437,6 +449,7 @@ impl Config {
             .into_iter()
             .flatten()
             .collect();
+        trace!("load_env: entries: {:#?}", entries);
         EnvResults::resolve(&env::PRISTINE_ENV, entries)
     }
 
