@@ -53,8 +53,7 @@ mod runtime_symlinks;
 mod shell;
 mod shims;
 mod shorthands;
-mod task;
-mod task_parser;
+pub(crate) mod task;
 pub(crate) mod tera;
 pub(crate) mod timeout;
 mod toml;
